<?php

declare(strict_types=1);

namespace Apexl\Io\Logger\Dtos\HandlerConfigParams;

use Apexl\Io\Logger\Dtos\HandlerConfigParams;

class DatabaseHandlerConfigParams extends HandlerConfigParams
{
    public string $table;
}
