<?php

declare(strict_types=1);

namespace Apexl\Io\Logger\Enums;

enum Handler : string
{
    case ERROR_LOG = 'error_log';
    case FILE = 'file';
    case LOGSTASH = 'logstash';
    case DATABASE = 'database';
    case MAIL = 'mail';
    case SLACK = 'slack';
    case GOOGLE_CHAT = 'google_chat';
}
