<?php

declare(strict_types=1);

namespace Apexl\Io\Logger\Interfaces;

use Apexl\Io\Logger\Dtos\HandlerConfig;
use Apexl\Io\Logger\Dtos\StreamConfig;
use Monolog\Handler\HandlerInterface;

interface HandlerCreatorInterface
{
    public function create(
        string $streamName,
        HandlerConfig $handlerConfig,
        StreamConfig $streamConfig,
    ): HandlerInterface;
}
