<?php

declare(strict_types=1);

namespace Apexl\Io\Logger\Dtos;

use Spatie\DataTransferObject\DataTransferObjectCollection;

/**
 * @method streamConfig current
 */
class StreamConfigCollection extends DataTransferObjectCollection
{
}
