<?php

declare(strict_types=1);

namespace Apexl\Io\Cache\Collections;

use Apexl\Io\Cache\Interfaces\CacheStreamInterface;
use Arrayy\Collection\AbstractCollection;

final class CacheStreamCollection extends AbstractCollection
{

    public function getType(): string
    {
        return CacheStreamInterface::class;
    }
}