<?php


return [
    'host' => \Apexl\Io\env('SMTP_HOST', 'localhost'),
    'auth' => filter_var(\Apexl\Io\env('SMTP_AUTH', false), FILTER_VALIDATE_BOOL),
    'username' => \Apexl\Io\env('SMTP_USERNAME', ''),
    'password' => \Apexl\Io\env('SMTP_PASSWORD', ''),
    'port' => \Apexl\Io\env('SMTP_PORT', '1025'),
    'from' => \Apexl\Io\env('SMTP_FROM', 'noreply@example.com'),
    'encryption' => filter_var(\Apexl\Io\env('SMTP_ENCRYPTION', false), FILTER_VALIDATE_BOOL),
];