<?php

namespace Apexl\Io\Modules;

use Apexl\Io\Authentication\Controllers\AuthenticatedController;
use Apexl\Io\Module;
use Apexl\Io\System\Interfaces\ProvidesRoutesInterface;

readonly class AuthenticationModule extends Module implements ProvidesRoutesInterface
{
    public function routes(): void
    {
        $this->get('/authenticated', AuthenticatedController::class)
            ->setName('core.authenticated');
    }
}
