<?php

declare(strict_types=1);

namespace Apexl\Io\System\Collections;

use Apexl\Io\Interfaces\IoModuleInterface;
use Arrayy\Arrayy;
use Arrayy\Collection\AbstractCollection;

/**
 * @extends Arrayy<array-key, IoModuleInterface>
 */
final class ModuleCollection extends AbstractCollection
{

    public function getType(): string
    {
        return IoModuleInterface::class;
    }
}