<?php

declare(strict_types=1);

namespace Apexl\Io\Services;

use Apexl\Io\System;
use Money\Currency;

final readonly class CurrencyFactory
{

    public function currency(string $code): Currency
    {
        return System::makeRegisteredService(Currency::class, [
            'code' => $code,
        ]);
    }
}