<?php

declare(strict_types=1);

namespace Apexl\Io\Logger\Dtos\HandlerConfigParams;

use Apexl\Io\Logger\Dtos\HandlerConfigParams;

class LogstashHandlerConfigParams extends HandlerConfigParams
{
    public string $host = 'localhost';
    public int $port = 50000;
    public ?string $application;
    public ?string $system;
}
