<?php

declare(strict_types=1);

namespace Apexl\Io\Interfaces;

use Apexl\Vault\Interfaces\QueryBuilderInterface;

interface QueryDecorator
{
    public function decorate(RelationshipInterface $relationship, QueryBuilderInterface $query): QueryBuilderInterface;
}
