<?php

declare(strict_types=1);

namespace Apexl\Io\Cache\Interfaces;

interface CacheManagerInterface
{
    public function default(): CacheStreamInterface;

    public function stream(string $name): CacheStreamInterface;

    public function clearAll(): void;

}
